parade.api package
==================

Submodules
----------

parade.api.data module
----------------------

.. automodule:: parade.api.data
    :members:
    :undoc-members:
    :show-inheritance:

parade.api.exec module
----------------------

.. automodule:: parade.api.exec
    :members:
    :undoc-members:
    :show-inheritance:

parade.api.flow module
----------------------

.. automodule:: parade.api.flow
    :members:
    :undoc-members:
    :show-inheritance:

parade.api.task module
----------------------

.. automodule:: parade.api.task
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: parade.api
    :members:
    :undoc-members:
    :show-inheritance:
